<?php

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

//if ( !class_exists('WPsite_Popup_Functions') ) :

add_action( 'wp_footer',	array('WPsite_Popup_Functions', 'display'));

// AJAX call to get all tags and custom posts

add_action( 'wp_ajax_wps_pf_set_close_cookie', 			array('WPsite_Popup_Functions', 'set_close_cookie'));
add_action( 'wp_ajax_nopriv_wps_pf_set_close_cookie', 	array('WPsite_Popup_Functions', 'set_close_cookie'));

/**
 *
 * Main class used to display the popup on the website and display backend options
 *
 * @since 1.0.0
 */
class WPsite_Popup_Functions {

	/**
	 * Hook function to wp_footer to display popup on website
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function display() {

		include_once(WPSITE_POPUP_PLUGIN_DIR . '/admin/model/db.php');

		global $wpdb;
		global $post;
		global $cat;

		$data = $wpdb->get_results("SELECT * FROM `" . WPsite_Popup_DB::getTableName() . "`",'ARRAY_A');

        $done = false;

        // Get all post types that are public

		$post_types = get_post_types(array('public' => true));

		// Post Types

		if (!$done && is_singular()) {

			foreach ($data as $val) {

	        	$args         = self::mb_unserialize($val['args']);
	        	$template     = self::mb_unserialize($val['template']);
        		$trigger      = self::mb_unserialize($val['trigger']);
        		$social       = self::mb_unserialize($val['social']);
        		$news_letter  = self::mb_unserialize($val['news_letter']);

        		// Check that conditions are true

        		if (!self::check_conditions($val['id'], $template, $args, $trigger)) {
	        		continue;
        		}

        		$post_ids = array();

        		if (isset($trigger[$post->post_type]['id'])) {
	        		$post_ids = explode(',', $trigger[$post->post_type]['id']);
        		}

	    		// Check if post types match

	    		if (isset($trigger['display_on']) && $trigger['display_on'] != $post->post_type) {
		    		continue;
	    		}

        		// ID

        		if (isset($trigger[$post->post_type]['all']) &&
        			!$trigger[$post->post_type]['all'] &&
	    			in_array($post->ID, $post_ids) &&
	    			$val['active'] == 'Active' &&
	    			!$done &&
	    			self::check_transient(WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args)) {

	        		self::generate_code($val, $social, $news_letter);

	        		if ($args['dismiss'] != 'no') {
	        			set_transient( WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args['dismiss'], (int) $args['dismiss'] * 60);
	        		}

	        		$done = true;
					break;
        		}
	        }

			foreach ($data as $val) {

	        	$args         = self::mb_unserialize($val['args']);
	        	$template     = self::mb_unserialize($val['template']);
        		$trigger      = self::mb_unserialize($val['trigger']);
        		$social       = self::mb_unserialize($val['social']);
        		$news_letter  = self::mb_unserialize($val['news_letter']);

        		// Check that conditions are true

        		if (!self::check_conditions($val['id'], $template, $args, $trigger)) {
	        		continue;
        		}

        		$post_ids = array();

        		if (isset($trigger[$post->post_type]['id'])) {
	        		$post_ids = explode(',', $trigger[$post->post_type]['id']);
        		}

	    		// Check if post types match

	    		if (isset($trigger['display_on']) &&
	    			$trigger['display_on'] != $post->post_type &&
	    			$trigger['display_on'] != 'category' &&
	    			$trigger['display_on'] != 'tag') {

					continue;
		    	}

		    	// Tag ID

		    	$tags = explode(',', $trigger['tag']['id']);

        		if ($trigger['display_on'] == 'tag' &&
        			has_tag($tags,$post->ID) &&
        			$val['active'] == 'Active' &&
        			!$done &&
        			self::check_transient(WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args)) {

	        		self::generate_code($val, $social, $news_letter);
	        		if ($args['dismiss'] != 'no') {
	        			set_transient( WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args['dismiss'], (int) $args['dismiss'] * 60);
	        		}

	        		$done = true;
					break;
        		}

        		// Category ID

        		if ($trigger['display_on'] == 'category' &&
        			isset($trigger['category']['all']) &&
        			!$trigger['category']['all'] &&
	        		$val['active'] == 'Active' &&
        			in_category($category_ids, $post->ID) &&
        			!$done &&
	    			self::check_transient(WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args)) {

	        		self::generate_code($val, $social, $news_letter);
	        		if ($args['dismiss'] != 'no') {
	        			set_transient( WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args['dismiss'], (int) $args['dismiss'] * 60);
	        		}

	        		$done = true;
					break;
        		}

        		// All

        		if ($trigger['display_on'] != 'category' &&
        			$trigger['display_on'] != 'tag' &&
        			isset($trigger[$post->post_type]['all']) &&
        			$trigger[$post->post_type]['all'] &&
        			$val['active'] == 'Active' &&
        			!$done &&
	    			self::check_transient(WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args)) {

	        		self::generate_code($val, $social, $news_letter);

	        		if ($args['dismiss'] != 'no') {
	        			set_transient( WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args['dismiss'], (int) $args['dismiss'] * 60);
	        		}
	        		$done = true;
					break;
        		}
	        }
		}

        // Tag

        if (!$done && is_tag()) {
	        foreach ($data as $val) {

	        	$args         = self::mb_unserialize($val['args']);
	        	$template     = self::mb_unserialize($val['template']);
        		$trigger      = self::mb_unserialize($val['trigger']);
        		$social       = self::mb_unserialize($val['social']);
        		$news_letter  = self::mb_unserialize($val['news_letter']);

        		// Check that conditions are true

        		if (!self::check_conditions($val['id'], $template, $args, $trigger)) {
	        		continue;
        		}

        		$social = self::mb_unserialize($val['social']);
        		$news_letter = self::mb_unserialize($val['news_letter']);
        		$tags = explode(',', $trigger['tag']['id']);

        		if ($trigger['display_on'] == 'tag' &&
        			is_tag($tags) &&
        			$val['active'] == 'Active' &&
        			!$done &&
	    			self::check_transient(WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args)) {

	        		self::generate_code($val, $social, $news_letter);

	        		if ($args['dismiss'] != 'no') {
	        			set_transient( WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args['dismiss'], (int) $args['dismiss'] * 60);
	        		}
	        		$done = true;
					break;
        		}
	        }
        }

		// Category

        if (!$done && (is_category() || is_single())) {

	        foreach ($data as $val) {

	        	$args         = self::mb_unserialize($val['args']);
	        	$template     = self::mb_unserialize($val['template']);
        		$trigger      = self::mb_unserialize($val['trigger']);
        		$social       = self::mb_unserialize($val['social']);
        		$news_letter  = self::mb_unserialize($val['news_letter']);

        		// Check that conditions are true

        		if (!self::check_conditions($val['id'], $template, $args, $trigger)) {
	        		continue;
        		}

        		$social = self::mb_unserialize($val['social']);
        		$news_letter = self::mb_unserialize($val['news_letter']);
        		$category_ids = explode(',', $trigger['category']['id']);

        		if ($trigger['display_on'] != 'category' || $val['active'] != 'Active' || $done) {
	        		continue;
        		}

        		// ID

        		if (!$done &&
        			isset($trigger['category']['all']) &&
	        		!$trigger['category']['all'] &&
        			(is_category() && in_array($cat, $category_ids)) ||
        			(is_singular() && in_category($category_ids, $post->ID)) &&
	    			self::check_transient(WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args)) {

	        		self::generate_code($val, $social, $news_letter);

	        		if ($args['dismiss'] != 'no') {
	        			set_transient( WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args['dismiss'], (int) $args['dismiss'] * 60);
	        		}
	        		$done = true;
					break;
        		}
	        }

	        foreach ($data as $val) {

	        	$args         = self::mb_unserialize($val['args']);
	        	$template     = self::mb_unserialize($val['template']);
        		$trigger      = self::mb_unserialize($val['trigger']);
        		$social       = self::mb_unserialize($val['social']);
        		$news_letter  = self::mb_unserialize($val['news_letter']);

        		// Check that conditions are true

        		if (!self::check_conditions($val['id'], $template, $args, $trigger)) {
	        		continue;
        		}

        		$social = self::mb_unserialize($val['social']);
        		$news_letter = self::mb_unserialize($val['news_letter']);
        		$category_ids = explode(',', $trigger['category']['id']);

        		if ($trigger['display_on'] != 'category' || $val['active'] != 'Active' || $done) {
	        		continue;
        		}

        		// All

        		if (!$done &&
        			isset($trigger['category']['all']) &&
        			$trigger['category']['all'] &&
        			is_category() &&
	    			self::check_transient(WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args)) {

	        		self::generate_code($val, $social, $news_letter);

	        		if ($args['dismiss'] != 'no') {
	        			set_transient( WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args['dismiss'], (int) $args['dismiss'] * 60);
	        		}
	        		$done = true;
					break;
        		}
	        }
        }

        // Archive

        if (!$done && is_archive()) {
	        foreach ($data as $val) {

	        	$args         = self::mb_unserialize($val['args']);
	        	$template     = self::mb_unserialize($val['template']);
        		$trigger      = self::mb_unserialize($val['trigger']);
        		$social       = self::mb_unserialize($val['social']);
        		$news_letter  = self::mb_unserialize($val['news_letter']);

        		// Check that conditions are true

        		if (!self::check_conditions($val['id'], $template, $args, $trigger)) {
	        		continue;
        		}

        		if ($trigger['display_on'] == 'archive' &&
        			$val['active'] == 'Active' &&
        			!$done &&
	    			self::check_transient(WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args)) {

	        		self::generate_code($val, $social, $news_letter);

	        		if ($args['dismiss'] != 'no') {
	        			set_transient( WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args['dismiss'], (int) $args['dismiss'] * 60);
	        		}
	        		$done = true;
					break;
        		}
	        }
        }

        // Front Page

        if (!$done && is_front_page()) {
	        foreach ($data as $val) {

	        	$args         = self::mb_unserialize($val['args']);
	        	$template     = self::mb_unserialize($val['template']);
        		$trigger      = self::mb_unserialize($val['trigger']);
        		$social       = self::mb_unserialize($val['social']);
        		$news_letter  = self::mb_unserialize($val['news_letter']);

        		// Check that conditions are true

        		if (!self::check_conditions($val['id'], $template, $args, $trigger)) {
	        		continue;
        		}

        		if ($trigger['display_on'] == 'frontpage' &&
        			$val['active'] == 'Active' &&
        			!$done &&
	    			self::check_transient(WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args)) {

	        		self::generate_code($val, $social, $news_letter);

	        		if ($args['dismiss'] != 'no') {
	        			set_transient( WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args['dismiss'], (int) $args['dismiss'] * 60);
	        		}
	        		$done = true;
					break;
        		}
	        }
        }

        // Site

        if (!$done) {
	        foreach ($data as $val) {

	        	$args         = self::mb_unserialize($val['args']);
	        	$template     = self::mb_unserialize($val['template']);
        		$trigger      = self::mb_unserialize($val['trigger']);
        		$social       = self::mb_unserialize($val['social']);
        		$news_letter  = self::mb_unserialize($val['news_letter']);

        		// Check that conditions are true

        		if (!self::check_conditions($val['id'], $template, $args, $trigger)) {
	        		continue;
        		}

        		if ($trigger['display_on'] == 'site' &&
        			$val['active'] == 'Active' &&
        			!$done &&
	    			self::check_transient(WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args)) {

	        		self::generate_code($val, $social, $news_letter);

	        		if ($args['dismiss'] != 'no') {
	        			set_transient( WPsite_Popup::$prefix . 'dismiss_' . $val['id'] . '_' . $_SERVER['REMOTE_ADDR'], $args['dismiss'], (int) $args['dismiss'] * 60);
	        		}
	        		$done = true;
					break;
        		}
	        }
        }
	}

	/**
	 * Adds the scripts and localizes the variables
	 *
	 * @since 1.0.0
	 *
	 * @param 	$val array of attrs
	 * @return 	N/A
	 */
	static function generate_scripts($val) {

		$args           = self::mb_unserialize($val['args']);
    	$template  		= self::mb_unserialize($val['template']);
		$trigger      	= self::mb_unserialize($val['trigger']);
		$social       	= self::mb_unserialize($val['social']);
		$news_letter  	= self::mb_unserialize($val['news_letter']);
		$style        	= self::mb_unserialize($val['style']);

		wp_enqueue_style(
			WPsite_Popup::$prefix . 'template_' . $template['type'] . '_css',
			WPSITE_POPUP_PLUGIN_URL . '/templates/template-' . $template['type'] . '/template-' . $template['type'] . '.css'
		);

		wp_enqueue_style(
			WPsite_Popup::$prefix . 'css',
			WPSITE_POPUP_PLUGIN_URL . '/templates/popup-fire.css'
		);

		wp_enqueue_style(
			WPsite_Popup::$prefix . 'fontawesome_css',
			WPSITE_POPUP_PLUGIN_URL . '/admin/fonts/font-awesome.min.css'
		);

		// Google Font Loader

		if (isset($style['google_fonts']) && $style['google_fonts']) {

			wp_enqueue_script(
				WPsite_Popup::$prefix . 'google_font_js',
				WPSITE_POPUP_PLUGIN_URL .  '/core/js/webfontloader.js'
			);

		}

		include_once(WPSITE_POPUP_PLUGIN_DIR . '/admin/functions.php');

		$default_popup = WPsite_Popups_Admin_Functions::default_popup();

	    $args_array = array(
			'prefix_dash'            => WPsite_Popup::$prefix_dash,
			'template'               => $template['type'],
			'preview'                => isset($_GET['action']) && $_GET['action'] == 'preview' ? true : false,
			'ajaxurl'                => admin_url( 'admin-ajax.php' ),
			'MailChimp_url'          => $newsletter['MailChimp']['url'],
			'trigger_type'           => $trigger['args']['type'],
			'timer'                  => isset($trigger['args']['timer']) ? $trigger['args']['timer'] : $default_popup['trigger']['args']['timer'],
			'scroll'                 => isset($trigger['args']['scroll']) ? $trigger['args']['scroll'] : $default_popup['trigger']['args']['scroll'],
			'color'                  => isset($style['background_color']) ? $style['background_color'] : $default_popup['style']['background_color'],
			'border_color'           => isset($style['border_color']) ? $style['border_color'] : $default_popup['style']['border_color'],
			'text_color'             => isset($style['color']) ? $style['color'] : $default_popup['style']['color'],
			'social_color'           => isset($style['social_color']) ? $style['social_color'] : $default_popup['style']['social_color'],
			'nl_color'               => isset($style['nl_color']) ? $style['nl_color'] : $default_popup['style']['nl_color'],
			'nl_bg_color'            => isset($style['nl_bg_color']) ? $style['nl_bg_color'] : $default_popup['style']['nl_bg_color'],
			'yes_color'              => isset($style['yes_color']) ? $style['yes_color'] : $default_popup['style']['yes_color'],
			'yes_bg_color'           => isset($style['yes_bg_color']) ? $style['yes_bg_color'] : $default_popup['style']['yes_bg_color'],
			'no_color'               => isset($style['no_color']) ? $style['no_color'] : $default_popup['style']['no_color'],
			'no_bg_color'            => isset($style['no_bg_color']) ? $style['no_bg_color'] : $default_popup['style']['no_bg_color'],
			'font_size'              => isset($style['font_size']) ? $style['font_size'] : $default_popup['style']['font_size'],
	    	'font_weight'         	 => isset($style['font_weight']) ? $style['font_weight'] : $default_popup['style']['font_weight'],
	    	'google_fonts' 			 => isset($style['google_fonts']) ? $style['google_fonts'] : $default_popup['style']['google_fonts'],
	    	'font_family_heading' 	 => isset($style['font_family_heading']) ? $style['font_family_heading'] : $default_popup['style']['font_family_heading'],
	    	'font_family'         	 => isset($style['font_family']) ? $style['font_family'] : $default_popup['style']['font_family'],
	    	'dont_show_again'		 => isset($args['dont_show_again']) ? $args['dont_show_again'] : $default_popup['args']['dont_show_again'],
		);

		if (isset($_GET['action']) && $_GET['action'] == 'preview') {

			wp_enqueue_script(
				WPsite_Popup::$prefix . 'preview_js',
				WPSITE_POPUP_PLUGIN_URL . '/core/js/popup-fire.js', array('jquery')
			);

			wp_localize_script(WPsite_Popup::$prefix . 'preview_js', 'wps_pf_data', $args_array);

		} else {

			wp_enqueue_script(
				WPsite_Popup::$prefix . 'js',
				WPSITE_POPUP_PLUGIN_URL . '/core/js/popup-fire.js', array('jquery')
			);

			wp_localize_script(WPsite_Popup::$prefix . 'js', 'wps_pf_data', $args_array);
		}
	}

	/**
	 * Displays the popup
	 *
	 * @since 1.0.0
	 *
	 * @param 	$val the array of the popup attr
	 * @param 	$social the array of the popup attr
	 * @param 	$news letter the array of the popup attr
	 * @return 	N/A
	 */
	static function generate_code($val, $social, $news_letter) {

		if (!isset($_GET['action']) || (isset($_GET['action']) && $_GET['action'] != 'preview')) {
			// Check if this popup has any A/B Testing

			$args = self::mb_unserialize($val['args']);

			if ($args['ab_testing']['active'] && $args['ab_testing']['popup_id'] != '0') {

				$wpsite_popup_db 	= new WPsite_Popup_DB();
				$ab_popup 			= $wpsite_popup_db->get_data_from_id($args['ab_testing']['popup_id']);
				$ab_args 			= self::mb_unserialize($ab_popup['args']);

				// Check to make sure both popups have A/B Testing Active and that the popup ids match

				if (isset($ab_popup) &&
					$ab_args['ab_testing']['active'] &&
					$val['id'] == $ab_args['ab_testing']['popup_id'] &&
					$ab_popup['id'] == $args['ab_testing']['popup_id']) {

					// Randomly choose either popup

					if (rand(0, 1)) {
						$val 			= $ab_popup;
						$social 		= self::mb_unserialize($val['social']);
						$news_letter 	= self::mb_unserialize($val['news_letter']);
					}
				}
			}
		}

		// Include scripts

		self::generate_scripts($val);

		$template                 = self::mb_unserialize($val['template']);
		$trigger                  = self::mb_unserialize($val['trigger']);
		$style                 	  = self::mb_unserialize($val['style']);
		$args                	  = self::mb_unserialize($val['args']);
		$title                    = $val['title'];
		$text                     = $val['text'];
		$image                    = $val['image'];
		$aweber_customer_key      = $news_letter['aweber']['consumer_key'];
		$aweber_customer_secret   = $news_letter['aweber']['consumer_secret'];
		$aweber_access_key        = $news_letter['aweber']['access_key'];
		$aweber_access_secret     = $news_letter['aweber']['access_secret'];
		$aweber_account_id        = $news_letter['aweber']['account_id'];
		$aweber_list_id           = $news_letter['aweber']['list_id'];
		$feedburner_id            = $news_letter['feedburner']['id'];
		$news_letter_type         = $news_letter['type'];
		$custom                   = $val['custom'];

		// Create Background Pattern credit to http://www.patternify.com

		$background = '';

		// Backgound Image

		if ( isset($style['background_type']) && $style['background_type'] == 'image' ) {

			$background_image_attributes = wp_get_attachment_image_src($style["background_image"], 'medium'); // returns an array

			if( $background_image_attributes ) {
				$background = 'style="background-image: url(' . $background_image_attributes[0] . ');background-size: cover;"';
			}

		} else if ( isset($style['background_type']) && $style['background_type'] == 'pattern' ) {

			// Dots

			if ($style['background_pattern'] == 'dots') {
				$background = 'style="background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAAXNSR0IArs4c6QAAAB1JREFUGBljYGBg4AFiQoAYNYTMGJWHhgAxgckDACfCADFzWBHCAAAAAElFTkSuQmCC);"';
			}

			// Diagonal right

			else if ($style['background_pattern'] == 'diagonal_right') {
				$background = 'style="background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAAXNSR0IArs4c6QAAABVJREFUGBljYCAO8BCjbFQRA/WCAABg/gB584t6RwAAAABJRU5ErkJggg==);"';
			}

			// Diagonal left

			else if ($style['background_pattern'] == 'diagonal_left') {
				$background = 'style="background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAAXNSR0IArs4c6QAAABhJREFUGBljYGBg4AFiosGoYuSgomFoAABg/gB5Q6KWYgAAAABJRU5ErkJggg==);"';
			}

			// Grid

			else if ($style['background_pattern'] == 'grid') {
				$background = 'style="background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAAXNSR0IArs4c6QAAAB1JREFUGBljZGBg4AFiogBRCpmIMgqoaFQh3pACADLgACqd10PPAAAAAElFTkSuQmCC);"';
			}

			// Zig Zag

			else if ($style['background_pattern'] == 'zig_zag') {
				$background = 'style="background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAICAYAAADA+m62AAAAAXNSR0IArs4c6QAAADFJREFUGBljYMAEPJhCmCIwRTAaUwVQBF0SnQ/WhFUQXTMuRTBrCcnD1OG1EUURaRwAYKwAecAGMfQAAAAASUVORK5CYII=);"';
			}

			// Diamonds

			else if ($style['background_pattern'] == 'diamonds') {
				$background = 'style="background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAAXNSR0IArs4c6QAAAEVJREFUGBljYMAEPEAhEMYLkBUgs1E0YZPAEMMQQDICLgdnIEmiM3mY0EUI8fGZiiGHIQA0HZsY2FJkCWQ2VheBFGAoAgCw1ADb2LiCOQAAAABJRU5ErkJggg==);"';
			}

			// Hearts

			else if ($style['background_pattern'] == 'hearts') {
				$background = 'style="background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAAXNSR0IArs4c6QAAADlJREFUGBljYKA14EGzAM5nRJKACyKJwZhfmGAsQjSyiSC12Ez9ApJAV4iuGKwIJIgLYDMZl1oyxQFOKAMqAtJ4RAAAAABJRU5ErkJggg==);"';
			}

			// Circles

			else if ($style['background_pattern'] == 'circles') {
				$background = 'style="background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAAXNSR0IArs4c6QAAADNJREFUGBljYKAH4AFaAsJ4AbICZDaKJmwScDEmFKUkcOAmAPUgs7EaAVJAUBFWnSQJAgBkhAB7H4o0xwAAAABJRU5ErkJggg==);"';
			}

			// X Out

			else if ($style['background_pattern'] == 'x_out') {
				$background = 'style="background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAAXNSR0IArs4c6QAAADRJREFUGBljYKAl4MFiODYxsDJkCWQ2FjMYGEAKMBQxYVVKhCCySchsFK3YJLCJoWginwMAZIQAe7Ze2SMAAAAASUVORK5CYII=);"';
			}
		}

		include_once(WPSITE_POPUP_PLUGIN_DIR . '/templates/popup-fire.php');
	}

	/**
	 * Checks that all popup conditions are met
	 *
	 * @access public
	 * @static
	 * @param mixed $popup_id
	 * @param mixed $template
	 * @param mixed $args
	 * @param mixed $trigger
	 * @return void
	 */
	static function check_conditions($popup_id, $template, $args, $trigger) {

		global $post;

		// Check if user closed popup and dont not show is set to true

		if (isset($_COOKIE[WPsite_Popup::$prefix . 'close_' . $popup_id])) {
			return false;
		}

		// Check if user has already signed up

		if (in_array($template['type'], WPsite_Popup::$newsletter_templates) && isset($_COOKIE[WPsite_Popup::$prefix . 'email_success_' . $popup_id])) {
			return false;
		}

		// Check if mobile

    	if (isset($args['mobile']) && $args['mobile'] == 'no' && wp_is_mobile()) {
    		return false;
		}

		// Check user role

		if (!self::check_user_role($trigger['args'])) {
    		return false;
		}

		// Check referrer

		if (!self::check_referrer($trigger['args'])) {
			return false;
		}

		// Check for excluded posts

		if ( is_singular() &&
			 isset($trigger[$post->post_type]['exclude']) &&
			 in_array($post->ID, explode(',', $trigger[$post->post_type]['exclude'])) ) {

    		return false;
		}

		// Date Range

		$now = time();

		if (isset($args['start_date']) && isset($args['end_date']) &&
			(strtotime($args['start_date']) > $now || strtotime($args['end_date']) < $now)) {
    		return false;
		}

		return true;
	}

	/**
	 * Checks if the transient for that specifc popup matches the current cached time
	 *
	 * @access public
	 * @static
	 * @param mixed $name
	 * @param mixed $args
	 * @return void
	 */
	static function check_transient($name, $args) {

		// There is no transient data stored

		if (false === get_transient($name)) {
			delete_transient($name);
			return true;
		}

		// There is transient data but it does not match the current cached time so reset transient

		else {

			$data = get_transient($name);

			// Cached time has not changed so do not reset transient

			if ($data == (int) $args['dismiss']) {
				return false;
			}

			// Cached time has changed so reset transient

			else {
				return true;
			}
		}

		return false;
	}

	/**
	 * Determines if the referrer URL matches any given by the user
	 *
	 * @access public
	 * @static
	 * @param mixed $settings
	 * @return void
	 */
	static function check_referrer($settings) {

		// Return true any domain is checked

		if ($settings['referrer_type'] == 'any') {
			return true;
		}

		// Check is referrer domain matches ones given by user

		else if (isset($_SERVER["HTTP_REFERER"])) {

			$urls = explode(',', $settings['referrer']);
			$domain = parse_url($_SERVER["HTTP_REFERER"]);

			if (in_array($domain['host'], $urls)) {
				return true;
			}
		}

		return false;
	}

	/**
     * Check if the current user has access to backend / frontend based on his role compared with role from settings
     *
     * @access public
     * @static
     * @param mixed $settings
     * @return void
     */
    static function check_user_role($settings) {

		// Check if Everyone users is true

		if (isset($settings['users']) && $settings['users'] == 'everyone') {
			return true;
		}

		// Check if All users is true

		else if (isset($settings['users']) && $settings['users'] == 'logged_in' && is_user_logged_in()) {
			return true;
		}

		// Check if Logged Out Users is true

		else if (isset($settings['users']) && $settings['users'] == 'logged_out' && !is_user_logged_in()) {
			return true;
		}

		// Check if Specific User is true

		else if (isset($settings['users']) && $settings['users'] == 'specific' && is_user_logged_in()) {

			$is_allowed = false;
			global $wp_roles;
			$current_user = wp_get_current_user();

			foreach ($wp_roles->role_names as $role_name => $role) {

				if (isset($settings['user_roles'][$role_name]) && $settings['user_roles'][$role_name] && in_array($role_name, $current_user->roles)) {
					$is_allowed = true;
				}
			}

			return $is_allowed;
		}

        return false;
    }

    /**
     * Sets the close cookie so that the popup does not show after user closes it out
     *
     * @access public
     * @static
     * @return void
     */
    static function set_close_cookie() {

	    if (!isset($_POST['popup_id'])) {
		    echo 'Popup ID was not found so cookie could not be set.';
		    die();
	    }

	    setcookie(WPsite_Popup::$prefix . 'close_' . $_POST['popup_id'], true, 0, '/');

		echo 'Cookie was set';
		die();
    }

    /**
	 * Mulit-byte Unserialize
	 *
	 * UTF-8 will screw up a serialized string
	 *
	 * @access private
	 * @param string
	 * @return string
	 */
	static function mb_unserialize($string) {
	    $string2 = preg_replace_callback(
	        '!s:(\d+):"(.*?)";!s',
	        function($m){
	            $len = strlen($m[2]);
	            $result = "s:$len:\"{$m[2]}\";";
	            return $result;

	        },
	        $string);
	    return unserialize($string2);
	}

}

//endif;